@@ -1,12 +1,12 @@
-__version__='0.0.8'
+__version__='0.1.1'
 
 
-def __json_load(filename: str) -> dict:
+def json_load(filename: str) -> dict:
     import json
     with open(filename) as cfgfile:
         return json.load(cfgfile)
 
-def __load_yaml(filename: str) -> object:
+def load_yaml(filename: str) -> object:
     import yaml
     with open(filename, encoding="utf8") as fp:
         with fp.read() as bsfile:
